@@ -964,6 +964,8 @@ def create_project(project_name):
     create_trainer_file(project_name, directories['pl_wrapper'], 'iterable_dataset', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'plmodel', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'network_module', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'save_onnx', False, from_folder='pl_wrapper')
+
     create_empty_init_file(directories['pl_wrapper'])
     create_trainer_file(project_name, directories['trainer'], 'comparison', False)
     create_trainer_file(project_name, directories['trainer'], 'config', False)
@@ -1520,7 +1522,7 @@ def copy_deploy_files(main_dir):
     listOfFiles = list()
     for (dirpath, dirname, filenames) in os.walk(dir):
         dirpath = dirpath.replace(dir, '')
-        listOfFiles += [os.path.join(dirpath, file) for file in filenames]
+        listOfFiles = [os.path.join(dirpath, file) for file in filenames]
         for file_path in listOfFiles:
             with open(os.path.join(dir, file_path), 'r', encoding="utf8") as file:
                 try:
@@ -1529,25 +1531,18 @@ def copy_deploy_files(main_dir):
                     data = data.replace('{name-your-artifacts}', currentPipelineFolder)
                     dirToCreate = ''
                     if main_dir:
-                        dirToCreate = main_dir + '/'
-                    if not os.path.exists(dirToCreate + 'deploy'):
-                        os.makedirs(dirToCreate + 'deploy')
-                    if not os.path.exists(dirToCreate + file_path):
-                        f = open(dirToCreate + file_path, "w")
+                        dirToCreate = os.path.join(main_dir, dirpath)
+                    if not os.path.exists(dirToCreate):
+                        os.makedirs(dirToCreate)
+                    if not os.path.exists(os.path.join(main_dir, file_path)):
+                        f = open(os.path.join(main_dir, file_path), "w")
                         f.write(data)
                         f.close()
                         # Make sure that .sh files can be executed
-                        if (dirToCreate + file_path).endswith('.sh'):
+                        if (os.path.join(main_dir, file_path)).endswith('.sh'):
                             os.chmod(dirToCreate + file_path, 0o744)
                 except Exception as ex:
                     pass
-    # for item in os.listdir(dir):
-    #     s = os.path.join(dir, item)
-    #     d = os.path.join(main_dir, item)
-    #     if os.path.isdir(s):
-    #         shutil.copytree(s, d, False, None)
-    #     else:
-    #         shutil.copy2(s, d)
 
 
 def copy_cloud_eval_files(main_dir):
