@@ -43,7 +43,9 @@ config = {
         'save_last_model': False,
         'model_name': 'my_model.ckpt',
         'device': device,
-        'num_warmup_steps': 0
+        'num_warmup_steps': 0,
+        'save_checkpoint_as_onnx': False,
+        'average': 'micro'  # 'macro'
     },
     'trainer_config': {  # Do not change, training_config is dedicated to pytorch lighting trainer module and uses its exact params.
         'max_epochs': 1,
