@@ -2,6 +2,7 @@ import os
 
 from dsframework.base.trainer.train import ZIDSTrainClass
 from dsframework.base.trainer.pl_wrapper import *
+from trainer.pl_wrapper.save_onnx import ToOnnx
 
 ##
 # @file
@@ -30,6 +31,13 @@ class generatedClass(ZIDSTrainClass):
         if self.model_config['save_last_model']:
             self.save_model(os.path.join(self.save_path, self.model_config['model_name']))
 
+        if self.model_config.get('save_checkpoint_as_onnx', False):
+            checkpoint_path = self.trainer_config['callbacks'][0].best_model_path
+            print(f'best model path: {checkpoint_path}')
+
+            to_onnx = ToOnnx(model_config=self.model_config)
+            to_onnx.save_checkpoint_as_onnx(checkpoint_path, self.model)
+
         if self.trainer is None:
             raise Exception('Implement train process in train.py, execute() method.')
 
